@@ -2,7 +2,7 @@
  * 
  * score.c - scoring-related functions of Namazu
  * 
- * $Id: score.c,v 1.3 2001/02/28 08:20:16 baba Exp $
+ * $Id: score.c,v 1.3.4.2 2001/09/02 07:13:37 rug Exp $
  * 
  * Copyright (C) 2001 Hajime BABA  All rights reserved.
  * Copyright (C) 2001 Namazu Project All rights reserved.
@@ -31,7 +31,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <math.h>
 #include <errno.h>
 #include <time.h>
@@ -41,13 +40,21 @@
 #ifdef HAVE_SUPPORT_H
 #  include "support.h"
 #endif
-#if defined (HAVE_UNISTD_H)
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #else
-# if defined (_WIN32) && !defined (__CYGWIN__)
+# ifdef _WIN32
 # include <io.h>
 # endif
 #endif
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include "libnamazu.h"
 #include "util.h"
 #include "hlist.h"
