@@ -1,6 +1,6 @@
 /*
  * 
- * $Id: util.c,v 1.75 2000/12/18 09:02:06 knok Exp $
+ * $Id: util.c,v 1.75.4.2 2001/09/02 07:13:37 rug Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -29,7 +29,6 @@
 
 #include <assert.h>
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <stdarg.h>
@@ -44,6 +43,13 @@
 #ifdef HAVE_SUPPORT_H
 #  include "support.h"
 #endif
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include "libnamazu.h"
 #include "util.h"
 #include "i18n.h"
@@ -488,7 +494,7 @@ nmz_strerror(enum nmz_stat errnum)
 
     switch (errnum) {
     case ERR_FATAL:
-	msg = _("Fatal error occured!");
+	msg = _("Fatal error occurred!");
 	break;
     case ERR_TOO_LONG_QUERY:
         msg = _("Too long query");
